# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.0.1

import enum

import winrt.system
from winrt import _winrt_windows_devices_bluetooth_advertisement

__all__ = [
    "BluetoothLEAdvertisementFlags",
    "BluetoothLEAdvertisementPublisherStatus",
    "BluetoothLEAdvertisementType",
    "BluetoothLEAdvertisementWatcherStatus",
    "BluetoothLEScanningMode",
    "BluetoothLEAdvertisement",
    "BluetoothLEAdvertisementBytePattern",
    "BluetoothLEAdvertisementDataSection",
    "BluetoothLEAdvertisementDataTypes",
    "BluetoothLEAdvertisementFilter",
    "BluetoothLEAdvertisementPublisher",
    "BluetoothLEAdvertisementPublisherStatusChangedEventArgs",
    "BluetoothLEAdvertisementReceivedEventArgs",
    "BluetoothLEAdvertisementWatcher",
    "BluetoothLEAdvertisementWatcherStoppedEventArgs",
    "BluetoothLEManufacturerData",
]

class BluetoothLEAdvertisementFlags(enum.IntFlag):
    NONE = 0
    LIMITED_DISCOVERABLE_MODE = 0x1
    GENERAL_DISCOVERABLE_MODE = 0x2
    CLASSIC_NOT_SUPPORTED = 0x4
    DUAL_MODE_CONTROLLER_CAPABLE = 0x8
    DUAL_MODE_HOST_CAPABLE = 0x10

class BluetoothLEAdvertisementPublisherStatus(enum.IntEnum):
    CREATED = 0
    WAITING = 1
    STARTED = 2
    STOPPING = 3
    STOPPED = 4
    ABORTED = 5

class BluetoothLEAdvertisementType(enum.IntEnum):
    CONNECTABLE_UNDIRECTED = 0
    CONNECTABLE_DIRECTED = 1
    SCANNABLE_UNDIRECTED = 2
    NON_CONNECTABLE_UNDIRECTED = 3
    SCAN_RESPONSE = 4
    EXTENDED = 5

class BluetoothLEAdvertisementWatcherStatus(enum.IntEnum):
    CREATED = 0
    STARTED = 1
    STOPPING = 2
    STOPPED = 3
    ABORTED = 4

class BluetoothLEScanningMode(enum.IntEnum):
    PASSIVE = 0
    ACTIVE = 1
    NONE = 2

BluetoothLEAdvertisement = _winrt_windows_devices_bluetooth_advertisement.BluetoothLEAdvertisement
BluetoothLEAdvertisementBytePattern = _winrt_windows_devices_bluetooth_advertisement.BluetoothLEAdvertisementBytePattern
BluetoothLEAdvertisementDataSection = _winrt_windows_devices_bluetooth_advertisement.BluetoothLEAdvertisementDataSection
BluetoothLEAdvertisementDataTypes = _winrt_windows_devices_bluetooth_advertisement.BluetoothLEAdvertisementDataTypes
BluetoothLEAdvertisementFilter = _winrt_windows_devices_bluetooth_advertisement.BluetoothLEAdvertisementFilter
BluetoothLEAdvertisementPublisher = _winrt_windows_devices_bluetooth_advertisement.BluetoothLEAdvertisementPublisher
BluetoothLEAdvertisementPublisherStatusChangedEventArgs = _winrt_windows_devices_bluetooth_advertisement.BluetoothLEAdvertisementPublisherStatusChangedEventArgs
BluetoothLEAdvertisementReceivedEventArgs = _winrt_windows_devices_bluetooth_advertisement.BluetoothLEAdvertisementReceivedEventArgs
BluetoothLEAdvertisementWatcher = _winrt_windows_devices_bluetooth_advertisement.BluetoothLEAdvertisementWatcher
BluetoothLEAdvertisementWatcherStoppedEventArgs = _winrt_windows_devices_bluetooth_advertisement.BluetoothLEAdvertisementWatcherStoppedEventArgs
BluetoothLEManufacturerData = _winrt_windows_devices_bluetooth_advertisement.BluetoothLEManufacturerData
